Gitweb:     
http://git.kernel.org/git/?p=linux/kernel/git/torvalds/linux-2.6.git;a=commit;h=d0758bc334780d70266c1d1b974ed26f740a0819
Commit:     d0758bc334780d70266c1d1b974ed26f740a0819
Parent:     67ac58edf771b10f8e89bf9fe1ccf6c9b92ce063
Author:     Andrew Morton <[EMAIL PROTECTED]>
AuthorDate: Wed May 9 02:34:00 2007 -0700
Committer:  Linus Torvalds <[EMAIL PROTECTED]>
CommitDate: Wed May 9 12:30:51 2007 -0700

    phy: use flush_work_keventd()
    
    (akpm: bypassed maintainers, sorry.  There are other patches which depend on
    this)
    
    Cc: "Maciej W. Rozycki" <[EMAIL PROTECTED]>
    Cc: David Howells <[EMAIL PROTECTED]>
    Cc: Jeff Garzik <[EMAIL PROTECTED]>
    Cc: Oleg Nesterov <[EMAIL PROTECTED]>
    Signed-off-by: Andrew Morton <[EMAIL PROTECTED]>
    Signed-off-by: Linus Torvalds <[EMAIL PROTECTED]>
---
 drivers/net/phy/phy.c |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/drivers/net/phy/phy.c b/drivers/net/phy/phy.c
index eed433d..f445c46 100644
--- a/drivers/net/phy/phy.c
+++ b/drivers/net/phy/phy.c
@@ -662,10 +662,10 @@ int phy_stop_interrupts(struct phy_device *phydev)
                phy_error(phydev);
 
        /*
         * Finish any pending work; we might have been scheduled
         * to be called from keventd ourselves, though.
         */
-       run_scheduled_work(&phydev->phy_queue);
+       flush_work_keventd(&phydev->phy_queue);
 
        free_irq(phydev->irq, phydev);
 
-
@@ -662,10 +662,10 @@ int phy_stop_interrupts(struct phy_device *phydev)
 
        /*
-        * Finish any pending work; we might have been scheduled
-        * to be called from keventd ourselves, though.
+        * Finish any pending work; we might have been scheduled to be called
+        * from keventd ourselves, but flush_work_keventd() handles that.
         */
To unsubscribe from this list: send the line "unsubscribe git-commits-head" in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to